@@ -1,5 +1,5 @@
 package Lingua::EN::Syllable;
-$Lingua::EN::Syllable::VERSION = '0.26';
+$Lingua::EN::Syllable::VERSION = '0.27';
 # ABSTRACT: count the number of syllables in English words
 
 use 5.006;
@@ -46,10 +46,12 @@ our @SubSyl;
 	   'iu',
 	   'io',
 	   'ii',
+       'microor',
 	   '[aeiouym]bl$',     # -Vble, plus -mble
 	   '[aeiou]{3}',       # agreeable
 	   '^mc',
-	   'ism$',             # -isms
+	   'ism$',             # -ism
+	   'isms$',            # -isms
 	   '([^aeiouy])\1l$',  # middle twiddle battle bottle, etc.
 	   '[^l]lien',         # alien, salient [1]
            '^coa[dglx].',      # [2]
@@ -69,6 +71,8 @@ sub syllable {
     my(@scrugg,$syl);
 
     $word =~ tr/A-Z/a-z/;
+    return 2 if $word eq 'w';
+    return 1 if length($word) == 1;
     $word =~ s/\'//g; # fold contractions.  not very effective.
     $word =~ s/e$//;
     @scrugg = split(/[^aeiouy]+/, $word); # '-' should perhaps be added?
@@ -81,7 +85,6 @@ sub syllable {
     foreach (@AddSyl) {
       $syl++ if $word=~/$_/;
     }
-    $syl++ if length($word)==1;	# 'x'
     # count vowel groupings
     $syl += scalar(@scrugg);
     $syl=1 if $syl==0; # got no vowels? ("the", "crwth")
